#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 unliftio
version:              0.2.25.1
visibility:           public
id:                   unliftio-0.2.25.1-2In9ZMbNHRKIca2kbOdPHJ
key:                  unliftio-0.2.25.1-2In9ZMbNHRKIca2kbOdPHJ
license:              MIT
copyright:            2017 FP Complete
maintainer:           michael@snoyman.com
author:               Michael Snoyman, Francesco Mazzoli
homepage:
    https://github.com/fpco/unliftio/tree/master/unliftio#readme

synopsis:
    The MonadUnliftIO typeclass for unlifting monads to IO (batteries included)

description:
    Please see the documentation and README at <https://www.stackage.org/package/unliftio>

category:             Control
abi:                  e2619b3b2d82fb559f2c69afc715ab23
exposed:              True
exposed-modules:
    UnliftIO UnliftIO.Async UnliftIO.Chan UnliftIO.Concurrent
    UnliftIO.Directory UnliftIO.Environment UnliftIO.Exception
    UnliftIO.Exception.Lens UnliftIO.Foreign UnliftIO.IO
    UnliftIO.IO.File UnliftIO.IORef UnliftIO.Internals.Async
    UnliftIO.MVar UnliftIO.Memoize UnliftIO.Process UnliftIO.QSem
    UnliftIO.QSemN UnliftIO.STM UnliftIO.Temporary UnliftIO.Timeout

hidden-modules:       Paths_unliftio UnliftIO.IO.File.Posix
import-dirs:          /usr/lib/ghc-9.6.6/site-local/unliftio-0.2.25.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/unliftio-0.2.25.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/unliftio-0.2.25.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-unliftio
hs-libraries:         HSunliftio-0.2.25.1-2In9ZMbNHRKIca2kbOdPHJ
depends:
    async-2.2.6-IoWj97vUYPEHBO7shudLcv base-4.18.2.1
    bytestring-0.11.5.3 deepseq-1.4.8.1 directory-1.3.8.5
    filepath-1.4.300.1 process-1.6.19.0
    safe-exceptions-0.1.7.4-Fu6atzLnUEaHb3ZvnJFIFn stm-2.5.1.0
    time-1.12.2 transformers-0.6.1.0 unix-2.8.4.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY

haddock-interfaces:   /usr/share/doc/haskell-unliftio/html/unliftio.haddock
haddock-html:         /usr/share/doc/haskell-unliftio/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

